# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..misc import NormalizeProbabilityMapSet


def test_NormalizeProbabilityMapSet_inputs():
    input_map = dict(
        in_files=dict(),
        in_mask=dict(extensions=None, ),
    )
    inputs = NormalizeProbabilityMapSet.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_NormalizeProbabilityMapSet_outputs():
    output_map = dict(out_files=dict(), )
    outputs = NormalizeProbabilityMapSet.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..brains import BRAINSTrimForegroundInDirection


def test_BRAINSTrimForegroundInDirection_inputs():
    input_map = dict(
        BackgroundFillValue=dict(argstr='--BackgroundFillValue %s', ),
        args=dict(argstr='%s', ),
        closingSize=dict(argstr='--closingSize %d', ),
        directionCode=dict(argstr='--directionCode %d', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        headSizeLimit=dict(argstr='--headSizeLimit %f', ),
        inputVolume=dict(
            argstr='--inputVolume %s',
            extensions=None,
        ),
        numberOfThreads=dict(argstr='--numberOfThreads %d', ),
        otsuPercentileThreshold=dict(argstr='--otsuPercentileThreshold %f', ),
        outputVolume=dict(
            argstr='--outputVolume %s',
            hash_files=False,
        ),
    )
    inputs = BRAINSTrimForegroundInDirection.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_BRAINSTrimForegroundInDirection_outputs():
    output_map = dict(outputVolume=dict(extensions=None, ), )
    outputs = BRAINSTrimForegroundInDirection.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..image import Reorient


def test_Reorient_inputs():
    input_map = dict(
        in_file=dict(
            extensions=None,
            mandatory=True,
        ),
        orientation=dict(usedefault=True, ),
    )
    inputs = Reorient.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_Reorient_outputs():
    output_map = dict(
        out_file=dict(extensions=None, ),
        transform=dict(extensions=None, ),
    )
    outputs = Reorient.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..gtract import gtractTensor


def test_gtractTensor_inputs():
    input_map = dict(
        applyMeasurementFrame=dict(argstr='--applyMeasurementFrame ', ),
        args=dict(argstr='%s', ),
        b0Index=dict(argstr='--b0Index %d', ),
        backgroundSuppressingThreshold=dict(
            argstr='--backgroundSuppressingThreshold %d', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        ignoreIndex=dict(
            argstr='--ignoreIndex %s',
            sep=',',
        ),
        inputVolume=dict(
            argstr='--inputVolume %s',
            extensions=None,
        ),
        maskProcessingMode=dict(argstr='--maskProcessingMode %s', ),
        maskVolume=dict(
            argstr='--maskVolume %s',
            extensions=None,
        ),
        medianFilterSize=dict(
            argstr='--medianFilterSize %s',
            sep=',',
        ),
        numberOfThreads=dict(argstr='--numberOfThreads %d', ),
        outputVolume=dict(
            argstr='--outputVolume %s',
            hash_files=False,
        ),
        resampleIsotropic=dict(argstr='--resampleIsotropic ', ),
        size=dict(argstr='--size %f', ),
    )
    inputs = gtractTensor.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_gtractTensor_outputs():
    output_map = dict(outputVolume=dict(extensions=None, ), )
    outputs = gtractTensor.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..gtract import gtractInvertDisplacementField


def test_gtractInvertDisplacementField_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        baseImage=dict(
            argstr='--baseImage %s',
            extensions=None,
        ),
        deformationImage=dict(
            argstr='--deformationImage %s',
            extensions=None,
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        numberOfThreads=dict(argstr='--numberOfThreads %d', ),
        outputVolume=dict(
            argstr='--outputVolume %s',
            hash_files=False,
        ),
        subsamplingFactor=dict(argstr='--subsamplingFactor %d', ),
    )
    inputs = gtractInvertDisplacementField.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_gtractInvertDisplacementField_outputs():
    output_map = dict(outputVolume=dict(extensions=None, ), )
    outputs = gtractInvertDisplacementField.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..brains import BRAINSSnapShotWriter


def test_BRAINSSnapShotWriter_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        inputBinaryVolumes=dict(argstr='--inputBinaryVolumes %s...', ),
        inputPlaneDirection=dict(
            argstr='--inputPlaneDirection %s',
            sep=',',
        ),
        inputSliceToExtractInIndex=dict(
            argstr='--inputSliceToExtractInIndex %s',
            sep=',',
        ),
        inputSliceToExtractInPercent=dict(
            argstr='--inputSliceToExtractInPercent %s',
            sep=',',
        ),
        inputSliceToExtractInPhysicalPoint=dict(
            argstr='--inputSliceToExtractInPhysicalPoint %s',
            sep=',',
        ),
        inputVolumes=dict(argstr='--inputVolumes %s...', ),
        outputFilename=dict(
            argstr='--outputFilename %s',
            hash_files=False,
        ),
    )
    inputs = BRAINSSnapShotWriter.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_BRAINSSnapShotWriter_outputs():
    output_map = dict(outputFilename=dict(extensions=None, ), )
    outputs = BRAINSSnapShotWriter.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..preprocess import ComputeMask


def test_ComputeMask_inputs():
    input_map = dict(
        M=dict(),
        cc=dict(),
        m=dict(),
        mean_volume=dict(
            extensions=None,
            mandatory=True,
        ),
        reference_volume=dict(extensions=None, ),
    )
    inputs = ComputeMask.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_ComputeMask_outputs():
    output_map = dict(brain_mask=dict(extensions=None, ), )
    outputs = ComputeMask.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..modelgen import SpecifySparseModel


def test_SpecifySparseModel_inputs():
    input_map = dict(
        bids_amplitude_column=dict(
            exists=True,
            mandatory=False,
        ),
        bids_condition_column=dict(
            exists=True,
            mandatory=False,
            usedefault=True,
        ),
        bids_event_file=dict(
            mandatory=True,
            xor=['subject_info', 'event_files', 'bids_event_file'],
        ),
        event_files=dict(
            mandatory=True,
            xor=['subject_info', 'event_files', 'bids_event_file'],
        ),
        functional_runs=dict(
            copyfile=False,
            mandatory=True,
        ),
        high_pass_filter_cutoff=dict(mandatory=True, ),
        input_units=dict(mandatory=True, ),
        model_hrf=dict(),
        outlier_files=dict(copyfile=False, ),
        parameter_source=dict(usedefault=True, ),
        realignment_parameters=dict(copyfile=False, ),
        save_plot=dict(),
        scale_regressors=dict(usedefault=True, ),
        scan_onset=dict(usedefault=True, ),
        stimuli_as_impulses=dict(usedefault=True, ),
        subject_info=dict(
            mandatory=True,
            xor=['subject_info', 'event_files', 'bids_event_file'],
        ),
        time_acquisition=dict(mandatory=True, ),
        time_repetition=dict(mandatory=True, ),
        use_temporal_deriv=dict(requires=['model_hrf'], ),
        volumes_in_cluster=dict(usedefault=True, ),
    )
    inputs = SpecifySparseModel.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_SpecifySparseModel_outputs():
    output_map = dict(
        session_info=dict(),
        sparse_png_file=dict(extensions=None, ),
        sparse_svg_file=dict(extensions=None, ),
    )
    outputs = SpecifySparseModel.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..preprocess import DegreeCentrality


def test_DegreeCentrality_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        autoclip=dict(argstr='-autoclip', ),
        automask=dict(argstr='-automask', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_file=dict(
            argstr='%s',
            copyfile=False,
            extensions=None,
            mandatory=True,
            position=-1,
        ),
        mask=dict(
            argstr='-mask %s',
            extensions=None,
        ),
        num_threads=dict(
            nohash=True,
            usedefault=True,
        ),
        oned_file=dict(argstr='-out1D %s', ),
        out_file=dict(
            argstr='-prefix %s',
            extensions=None,
            name_source=['in_file'],
            name_template='%s_afni',
        ),
        outputtype=dict(),
        polort=dict(argstr='-polort %d', ),
        sparsity=dict(argstr='-sparsity %f', ),
        thresh=dict(argstr='-thresh %f', ),
    )
    inputs = DegreeCentrality.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_DegreeCentrality_outputs():
    output_map = dict(
        oned_file=dict(extensions=None, ),
        out_file=dict(extensions=None, ),
    )
    outputs = DegreeCentrality.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



#!/usr/bin/env python3
import json
from fuzzywuzzy import fuzz, process
import shutil
import os
import subprocess as sp

if os.path.exists('line-contributions.txt'):
    with open('line-contributions.txt', 'rt') as fp:
        lines = fp.readlines()
else:
    if shutil.which('git-line-summary'):
        print("Running git-line-summary on nipype repo")
        lines = sp.check_output(['git-line-summary']).decode().split('\n')
    else:
        raise RuntimeError("Install Git Extras to view git contributors")

data = [' '.join(line.strip().split()[1:-1]) for line in lines if '%' in line]

# load zenodo from master
with open('.zenodo.json', 'rt') as fp:
    zenodo = json.load(fp)
zen_names = [' '.join(val['name'].split(',')[::-1]).strip()
             for val in zenodo['creators']]

name_matches = []

for ele in data:
    matches = process.extract(ele, zen_names, scorer=fuzz.token_sort_ratio,
                              limit=2)
    # matches is a list [('First match', % Match), ('Second match', % Match)]
    if matches[0][1] > 80:
        val = zenodo['creators'][zen_names.index(matches[0][0])]
    else:
        # skip unmatched names
        print("No entry to sort:", ele)
        continue

    if val not in name_matches:
        name_matches.append(val)

# for entries not found in line-contributions
missing_entries = [
    {"name": "Varada, Jan"},
    {"name": "Schwabacher, Isaac"},
    {"affiliation": "Child Mind Institute / Nathan Kline Institute",
     "name": "Pellman, John",
     "orcid": "0000-0001-6810-4461"},
    {"name": "Perez-Guevara, Martin"},
    {"name": "Khanuja, Ranjeet"},
    {"affiliation":
        "Medical Imaging & Biomarkers, Bioclinica, Newark, CA, USA.",
     "name": "Pannetier, Nicolas",
     "orcid": "0000-0002-0744-5155"},
    {"name": "McDermottroe, Conor"},
    {"affiliation":
        "Max Planck Institute for Human Cognitive and Brain Sciences, "
        "Leipzig, Germany.",
     "name": "Mihai, Paul Glad",
     "orcid": "0000-0001-5715-6442"},
    {"name": "Lai, Jeff"}
]

for entry in missing_entries:
    name_matches.append(entry)


def fix_position(creators):
    # position first / last authors
    f_authr = None
    l_authr = None

    for i, info in enumerate(creators):
        if info['name'] == 'Gorgolewski, Krzysztof J.':
            f_authr = i
        if info['name'] == 'Ghosh, Satrajit':
            l_authr = i

    if f_authr is None or l_authr is None:
        raise AttributeError('Missing important people')

    creators.insert(0, creators.pop(f_authr))
    creators.insert(len(creators), creators.pop(l_authr + 1))
    return creators


zenodo['creators'] = fix_position(name_matches)

with open('.zenodo.json', 'wt') as fp:
    json.dump(zenodo, fp, indent=2, sort_keys=True)
    fp.write('\n')



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..registration import ComposeXfmTask


def test_ComposeXfmTask_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_aff=dict(
            argstr='-aff %s',
            extensions=None,
            mandatory=True,
        ),
        in_df=dict(
            argstr='-df %s',
            extensions=None,
            mandatory=True,
        ),
        out_file=dict(
            argstr='-out %s',
            extensions=None,
            genfile=True,
        ),
    )
    inputs = ComposeXfmTask.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_ComposeXfmTask_outputs():
    output_map = dict(out_file=dict(extensions=None, ), )
    outputs = ComposeXfmTask.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..registration import Paint


def test_Paint_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        averages=dict(argstr='-a %d', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_surf=dict(
            argstr='%s',
            extensions=None,
            mandatory=True,
            position=-2,
        ),
        out_file=dict(
            argstr='%s',
            extensions=None,
            hash_files=False,
            keep_extension=False,
            name_source=['in_surf'],
            name_template='%s.avg_curv',
            position=-1,
        ),
        subjects_dir=dict(),
        template=dict(
            argstr='%s',
            extensions=None,
            mandatory=True,
            position=-3,
        ),
        template_param=dict(),
    )
    inputs = Paint.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_Paint_outputs():
    output_map = dict(out_file=dict(extensions=None, ), )
    outputs = Paint.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value
